==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/outputs/WebAclLoggingConfigurationLoggingFilterFilterCondition.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property actionCondition Configuration for a single action condition. See Action Condition below for more details.
 * @property labelNameCondition Condition for a single label name. See Label Name Condition below for more details.
 */
public data class WebAclLoggingConfigurationLoggingFilterFilterCondition(
    public val actionCondition: WebAclLoggingConfigurationLoggingFilterFilterConditionActionCondition? =
        null,
    public val labelNameCondition:
    WebAclLoggingConfigurationLoggingFilterFilterConditionLabelNameCondition? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.wafv2.outputs.WebAclLoggingConfigurationLoggingFilterFilterCondition):
            WebAclLoggingConfigurationLoggingFilterFilterCondition =
            WebAclLoggingConfigurationLoggingFilterFilterCondition(
                actionCondition = javaType.actionCondition().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.wafv2.kotlin.outputs.WebAclLoggingConfigurationLoggingFilterFilterConditionActionCondition.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                labelNameCondition = javaType.labelNameCondition().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.wafv2.kotlin.outputs.WebAclLoggingConfigurationLoggingFilterFilterConditionLabelNameCondition.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/outputs/WebAclLoggingConfigurationLoggingFilterFilterCondition.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property actionCondition Configuration for a single action condition. See Action Condition below for more details.
 * @property labelNameCondition Condition for a single label name. See Label Name Condition below for more details.
 */
public data class WebAclLoggingConfigurationLoggingFilterFilterCondition(
    public val actionCondition: WebAclLoggingConfigurationLoggingFilterFilterConditionActionCondition? =
        null,
    public val labelNameCondition: WebAclLoggingConfigurationLoggingFilterFilterConditionLabelNameCondition? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.wafv2.outputs.WebAclLoggingConfigurationLoggingFilterFilterCondition): WebAclLoggingConfigurationLoggingFilterFilterCondition =
            WebAclLoggingConfigurationLoggingFilterFilterCondition(
                actionCondition = javaType.actionCondition().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.wafv2.kotlin.outputs.WebAclLoggingConfigurationLoggingFilterFilterConditionActionCondition.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                labelNameCondition = javaType.labelNameCondition().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.wafv2.kotlin.outputs.WebAclLoggingConfigurationLoggingFilterFilterConditionLabelNameCondition.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}
